@@ -32,7 +32,7 @@ into namespaces separated by underscores (_).
 """
 from typing import Any
 
-from leanai.core.logging import debug
+from leanai.core.logging import DEBUG_LEVEL_CORE, debug
 
 
 class DictLike(dict):
@@ -79,7 +79,27 @@ class DictLike(dict):
             params = dict(**self)
             del params["type"]
             params.update(kwds)
-            debug(f"Calling DictLike(*{args}, **{params})")
+            debug(f"Calling DictLike(*{args}, **{params})", level=DEBUG_LEVEL_CORE)
             return constructor(*args, **params)
         else:
             raise AttributeError(f"Not callable as no type is availible: {self}")
+
+    @staticmethod
+    def from_dict(obj, ignore_non_dict=False):
+        if isinstance(obj, dict):
+            return DictLike(**{
+                k: DictLike.from_dict(v, ignore_non_dict=True)
+                for k, v in obj.items()
+            })
+        else:
+            if ignore_non_dict:
+                return obj
+            else:
+                raise TypeError(f"DictLike.from_dict expected a dict as input type but got {type(obj)}.")
+
+    @staticmethod
+    def try_build(obj):
+        if isinstance(obj, DictLike):
+            return obj()
+        else:
+            return obj
