@@ -2,7 +2,7 @@ from leanai.model.layers.activation import Activation
 from leanai.model.layers.batch_normalization import BatchNormalization
 from leanai.model.layers.convolution import Conv1D, Conv2D
 from leanai.model.layers.dense import Dense
-from leanai.model.layers.detection import DetectionHead, GridAnchorGenerator, DeltasToBoxes, ClipBox2DToImage, FilterLowScores, FilterSmallBoxes2D, NMS
+from leanai.model.layers.detection import DetectionHead, FilterBoxes2D, GridAnchorGenerator, DeltasToBoxes, ClipBox2DToImage, FilterLowScores, FilterSmallBoxes2D, NMS, DenseDetectionHead, ROIDetectionHead
 from leanai.model.layers.dropout import Dropout
 from leanai.model.layers.flatten import Flatten, VectorizeWithBatchIndices
 from leanai.model.layers.image_conversion import ImageConversion
