@@ -3,13 +3,9 @@
 
 > Compute an activation function.
 """
-from functools import partial
-import torch
 from torch.nn import Module
-from leanai.model.module_registry import register_module
 
 
-@register_module()
 class Activation(Module):
     def __init__(self, activation, **kwargs):
         """
